@@ -14,7 +14,7 @@ use Map::Tube::GraphViz::Utils qw(node_color);
 use Scalar::Util qw(blessed);
 
 # Version.
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 # Constructor.
 sub new {
@@ -332,7 +332,6 @@ L<Scalar::Util>.
 
 L<Map::Tube>,
 L<Map::Tube::Graph>,
-L<Map::Tube::GraphViz>,
 L<Map::Tube::Plugin::Graph>,
 L<Map::Tube::Text::Table>,
 L<Task::Map::Tube>.
@@ -351,7 +350,11 @@ L<http://skim.cz>
 
 =head1 CONTRIBUTORS
 
- Gisbert W. Selke
+=over
+
+=item Gisbert W. Selke L<gws@cpan.org>
+
+=back
 
 =head1 LICENSE AND COPYRIGHT
 
@@ -361,6 +364,6 @@ L<http://skim.cz>
 
 =head1 VERSION
 
-0.02
+0.03
 
 =cut
